You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2015/02/02 14:55:08 UTC

[2/3] incubator-ignite git commit: #IGNITE-106: Remove grid from comments.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
index c9b0539..d89b987 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample1.scala
@@ -59,12 +59,12 @@ object ScalarCacheAffinityExample1 {
 
             ('A' to 'Z').foreach(keys :+= _.toString)
 
-            populateCache(grid$, keys)
+            populateCache(ignite, keys)
 
             var results = Map.empty[String, String]
 
             keys.foreach(key => {
-                val res = grid$.call$(
+                val res = ignite.call$(
                     new Callable[String] {
                         @CacheAffinityKeyMapped
                         def affinityKey(): String = key
@@ -78,7 +78,7 @@ object ScalarCacheAffinityExample1 {
                             val cache = cache$[String, String](NAME)
 
                             if (!cache.isDefined) {
-                                println(">>> Cache not found [nodeId=" + grid$.cluster().localNode.id +
+                                println(">>> Cache not found [nodeId=" + ignite.cluster().localNode.id +
                                     ", cacheName=" + NAME + ']')
 
                                 "Error"

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
index e12f3bf..3dea5fd 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinityExample2.scala
@@ -53,17 +53,17 @@ object ScalarCacheAffinityExample2 {
 
             ('A' to 'Z').foreach(keys :+= _.toString)
 
-            populateCache(grid$, keys)
+            populateCache(ignite, keys)
 
             // Map all keys to nodes.
-            val mappings = grid$.cluster().mapKeysToNodes(NAME, keys)
+            val mappings = ignite.cluster().mapKeysToNodes(NAME, keys)
 
             mappings.foreach(mapping => {
                 val node = mapping._1
                 val mappedKeys = mapping._2
 
                 if (node != null) {
-                    grid$.cluster().forNode(node) *< (() => {
+                    ignite.cluster().forNode(node) *< (() => {
                         breakable {
                             println(">>> Executing affinity job for keys: " + mappedKeys)
 
@@ -73,7 +73,7 @@ object ScalarCacheAffinityExample2 {
                             // If cache is not defined at this point then it means that
                             // job was not routed by affinity.
                             if (!cache.isDefined)
-                                println(">>> Cache not found [nodeId=" + grid$.cluster().localNode().id() +
+                                println(">>> Cache not found [nodeId=" + ignite.cluster().localNode().id() +
                                     ", cacheName=" + NAME + ']').^^
 
                             // Check cache without loading the value.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
index 12c2f96..f6e12ca 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheAffinitySimpleExample.scala
@@ -53,7 +53,7 @@ object ScalarCacheAffinitySimpleExample extends App {
         // Clean up caches on all nodes before run.
         cache$(NAME).get.globalClearAll(0)
 
-        val c = grid$.cache[Int, String](NAME)
+        val c = ignite.cache[Int, String](NAME)
 
         populate(c)
         visit(c)
@@ -67,7 +67,7 @@ object ScalarCacheAffinitySimpleExample extends App {
      */
     private def visit(c: Cache) {
         (0 until KEY_CNT).foreach(i =>
-            grid$.compute().affinityRun(NAME, i,
+            ignite.compute().affinityRun(NAME, i,
                 () => println("Co-located [key= " + i + ", value=" + c.peek(i) + ']'))
         )
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
index 22ab99e..3855269 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheExample.scala
@@ -126,7 +126,7 @@ object ScalarCacheExample extends App {
      * so we can actually see what happens underneath locally and remotely.
      */
     def registerListener() {
-        val g = grid$
+        val g = ignite
 
         g *< (() => {
             val lsnr = new IgnitePredicate[IgniteEvent] {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
index 61347c3..108c415 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
@@ -45,7 +45,7 @@ object ScalarCacheQueryExample {
      */
     def main(args: Array[String]) {
         scalar("examples/config/example-cache.xml") {
-            example(grid$)
+            example(ignite)
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
index fc4b46b..4b37ea0 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarClosureExample.scala
@@ -41,7 +41,7 @@ object ScalarClosureExample extends App {
      * Prints grid topology.
      */
     def topology() {
-        grid$ foreach (n => println("Node: " + nid8$(n)))
+        ignite foreach (n => println("Node: " + nid8$(n)))
     }
 
     /**
@@ -51,31 +51,31 @@ object ScalarClosureExample extends App {
         // Notice the example usage of Java-side closure 'F.println(...)' and method 'scala'
         // that explicitly converts Java side object to a proper Scala counterpart.
         // This method is required since implicit conversion won't be applied here.
-        grid$.run$(for (w <- "Hello World!".split(" ")) yield () => println(w), null)
+        ignite.run$(for (w <- "Hello World!".split(" ")) yield () => println(w), null)
     }
 
     /**
      * Obligatory example - cloud enabled Hello World!
      */
     def helloWorld() {
-        grid$.run$("HELLO WORLD!".split(" ") map (w => () => println(w)), null)
+        ignite.run$("HELLO WORLD!".split(" ") map (w => () => println(w)), null)
     }
 
     /**
      * One way to execute closures on the grid.
      */
     def broadcast() {
-        grid$.bcastRun(() => println("Broadcasting!!!"), null)
+        ignite.bcastRun(() => println("Broadcasting!!!"), null)
     }
 
     /**
      *  Greats all remote nodes only.
      */
     def greetRemotes() {
-        val me = grid$.cluster().localNode.id
+        val me = ignite.cluster().localNode.id
 
         // Note that usage Java-based closure.
-        grid$.cluster().forRemotes() match {
+        ignite.cluster().forRemotes() match {
             case p if p.isEmpty => println("No remote nodes!")
             case p => p.bcastRun(() => println("Greetings from: " + me), null)
         }
@@ -85,11 +85,11 @@ object ScalarClosureExample extends App {
      * Same as previous greetings for all remote nodes but remote projection is created manually.
      */
     def greetRemotesAgain() {
-        val me = grid$.cluster().localNode.id
+        val me = ignite.cluster().localNode.id
 
         // Just show that we can create any projections we like...
         // Note that usage of Java-based closure via 'F' typedef.
-        grid$.cluster().forPredicate((n: ClusterNode) => n.id != me) match {
+        ignite.cluster().forPredicate((n: ClusterNode) => n.id != me) match {
             case p if p.isEmpty => println("No remote nodes!")
             case p => p.bcastRun(() => println("Greetings again from: " + me), null)
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
index 1c1dc46..85dd07e 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarContinuationExample.scala
@@ -48,21 +48,21 @@ object ScalarContinuationExample {
             // Calculate fibonacci for N.
             val N: Long = 100
 
-            val thisNode = grid$.cluster().localNode
+            val thisNode = ignite.cluster().localNode
 
             val start = System.currentTimeMillis
 
             // Projection that excludes this node if others exists.
-            val prj = if (grid$.cluster().nodes().size() > 1) grid$.cluster().forOthers(thisNode) else grid$.cluster().forNode(thisNode)
+            val prj = if (ignite.cluster().nodes().size() > 1) ignite.cluster().forOthers(thisNode) else ignite.cluster().forNode(thisNode)
 
-            val fib = grid$.compute(prj).apply(new FibonacciClosure(thisNode.id()), N)
+            val fib = ignite.compute(prj).apply(new FibonacciClosure(thisNode.id()), N)
 
             val duration = System.currentTimeMillis - start
 
             println(">>>")
             println(">>> Finished executing Fibonacci for '" + N + "' in " + duration + " ms.")
             println(">>> Fibonacci sequence for input number '" + N + "' is '" + fib + "'.")
-            println(">>> You should see prints out every recursive Fibonacci execution on grid nodes.")
+            println(">>> You should see prints out every recursive Fibonacci execution on cluster nodes.")
             println(">>> Check remote nodes for output.")
             println(">>>")
         }
@@ -95,7 +95,7 @@ class FibonacciClosure (
             // Make sure n is not negative.
             val n = math.abs(num)
 
-            val g = grid$
+            val g = ignite
 
             if (n <= 2)
                 return if (n == 0)
@@ -110,12 +110,12 @@ class FibonacciClosure (
             fut1 = store.get(n - 1)
             fut2 = store.get(n - 2)
 
-            val excludeNode = grid$.cluster().node(excludeNodeId)
+            val excludeNode = ignite.cluster().node(excludeNodeId)
 
             // Projection that excludes node with id passed in constructor if others exists.
-            val prj = if (grid$.cluster().nodes().size() > 1) grid$.cluster().forOthers(excludeNode) else grid$.cluster().forNode(excludeNode)
+            val prj = if (ignite.cluster().nodes().size() > 1) ignite.cluster().forOthers(excludeNode) else ignite.cluster().forNode(excludeNode)
 
-            val comp = grid$.compute(prj).withAsync()
+            val comp = ignite.compute(prj).withAsync()
 
             // If future is not cached in node-local store, cache it.
             // Note recursive grid execution!

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
index 65393f7..18b1fb3 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCreditRiskExample.scala
@@ -62,10 +62,10 @@ object ScalarCreditRiskExample {
             // Calculate credit risk and print it out.
             // As you can see the grid enabling is completely hidden from the caller
             // and it is fully transparent to him. In fact, the caller is never directly
-            // aware if method was executed just locally or on the 100s of grid nodes.
+            // aware if method was executed just locally or on the 100s of cluster nodes.
             // Credit risk crdRisk is the minimal amount that creditor has to have
             // available to cover possible defaults.
-            val crdRisk = grid$ @< (closures(grid$.cluster().nodes().size(), portfolio, horizon, iter, percentile),
+            val crdRisk = ignite @< (closures(ignite.cluster().nodes().size(), portfolio, horizon, iter, percentile),
                 (s: Seq[Double]) => s.sum / s.size, null)
 
             println("Credit risk [crdRisk=" + crdRisk + ", duration=" +

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
index 12b72b7..44244ac 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPiCalculationExample.scala
@@ -36,9 +36,9 @@ object ScalarPiCalculationExample {
 
     def main(args: Array[String]) {
         scalar("examples/config/example-compute.xml") {
-            val jobs = for (i <- 0 until grid$.cluster().nodes().size()) yield () => calcPi(i * N)
+            val jobs = for (i <- 0 until ignite.cluster().nodes().size()) yield () => calcPi(i * N)
 
-            println("Pi estimate: " + grid$.reduce$[Double, Double](jobs, _.sum, null))
+            println("Pi estimate: " + ignite.reduce$[Double, Double](jobs, _.sum, null))
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
index dbdd9e0..8eb0d8e 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPingPongExample.scala
@@ -41,7 +41,7 @@ object ScalarPingPongExample extends App {
      * Implements Ping Pong example between local and remote node.
      */
     def pingPong() {
-        val g = grid$
+        val g = ignite
 
         if (g.cluster().nodes().size < 2) {
             println(">>>")
@@ -71,7 +71,7 @@ object ScalarPingPongExample extends App {
 
             // Set up local player: configure local node 'loc'
             // to listen for messages from remote node 'rmt'.
-            grid$.message().localListen(null, new MessagingListenActor[String]() {
+            ignite.message().localListen(null, new MessagingListenActor[String]() {
                 def receive(nodeId: UUID, msg: String) {
                     println(msg)
 
@@ -96,7 +96,7 @@ object ScalarPingPongExample extends App {
      * Implements Ping Pong example between two remote nodes.
      */
     def pingPong2() {
-        val g = grid$
+        val g = ignite
 
         if (g.cluster().forRemotes().nodes().size() < 2) {
             println(">>>")

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
index 3a29101..25af7d7 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarPrimeExample.scala
@@ -39,7 +39,7 @@ import scala.util.control.Breaks._
  * output).
  *
  * Note that when running this example on a multi-core box, simply
- * starting additional grid node on the same box will speed up
+ * starting additional cluster node on the same box will speed up
  * prime number calculation by a factor of 2.
  */
 object ScalarPrimeExample {
@@ -58,7 +58,7 @@ object ScalarPrimeExample {
             println(">>>")
             println(">>> Starting to check the following numbers for primes: " + util.Arrays.toString(checkVals))
 
-            val g = grid$
+            val g = ignite
 
             checkVals.foreach(checkVal => {
                 val divisor = g.reduce$[Option[Long], Option[Option[Long]]](

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
index 299bc0f..05fec2c 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarScheduleExample.scala
@@ -22,7 +22,7 @@ import org.apache.ignite.scalar.scalar._
 
 /**
  * Demonstrates a cron-based `Runnable` execution scheduling.
- * Test runnable object broadcasts a phrase to all grid nodes every minute
+ * Test runnable object broadcasts a phrase to all cluster nodes every minute
  * three times with initial scheduling delay equal to five seconds.
  * <p>
  * Remote nodes should always be started with special configuration file which
@@ -33,12 +33,12 @@ object ScalarScheduleExample extends App {
         println()
         println("Compute schedule example started.")
 
-        val g = grid$
+        val g = ignite
 
         var invocations = 0
 
         // Schedule callable that returns incremented value each time.
-        val fut = grid$.scheduleLocalCall(
+        val fut = ignite.scheduleLocalCall(
             () => {
                 invocations += 1
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
index 87317d0..21c2b95 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarSnowflakeSchemaExample.scala
@@ -77,7 +77,7 @@ object ScalarSnowflakeSchemaExample {
      * `DimStore` and `DimProduct` instances.
      */
     def populateDimensions() {
-        val dimCache = grid$.jcache[Int, Object](REPL_CACHE_NAME)
+        val dimCache = ignite.jcache[Int, Object](REPL_CACHE_NAME)
 
         val store1 = new DimStore(idGen.next(), "Store1", "12345", "321 Chilly Dr, NY")
         val store2 = new DimStore(idGen.next(), "Store2", "54321", "123 Windy Dr, San Francisco")
@@ -99,7 +99,7 @@ object ScalarSnowflakeSchemaExample {
      * `FactPurchase` objects stored in `partitioned` cache.
      */
     def queryStorePurchases() {
-        val factCache = grid$.cache[Int, FactPurchase](PART_CACHE_NAME)
+        val factCache = ignite.cache[Int, FactPurchase](PART_CACHE_NAME)
 
         val storePurchases = factCache.sql(
             "from \"replicated\".DimStore, \"partitioned\".FactPurchase " +
@@ -115,8 +115,8 @@ object ScalarSnowflakeSchemaExample {
      * stored in `partitioned` cache.
      */
     private def queryProductPurchases() {
-        val dimCache = grid$.cache[Int, Object](REPL_CACHE_NAME)
-        val factCache = grid$.cache[Int, FactPurchase](PART_CACHE_NAME)
+        val dimCache = ignite.cache[Int, Object](REPL_CACHE_NAME)
+        val factCache = ignite.cache[Int, FactPurchase](PART_CACHE_NAME)
 
         val prods: CacheProjection[Int, DimProduct] = dimCache.viewByType(classOf[Int], classOf[DimProduct])
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
index fd63601..eac3efd 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarTaskExample.scala
@@ -36,7 +36,7 @@ import scala.collection.JavaConversions._
  */
 object ScalarTaskExample extends App {
     scalar("examples/config/example-compute.xml") {
-        grid$.compute().execute(classOf[GridHelloWorld], "Hello Cloud World!")
+        ignite.compute().execute(classOf[GridHelloWorld], "Hello Cloud World!")
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
----------------------------------------------------------------------
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
index 8d73cda..ce577ad 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarWorldShortestMapReduce.scala
@@ -33,7 +33,7 @@ object ScalarWorldShortestMapReduce extends App {
         val input = "World shortest mapreduce application"
 
         println("Non-space characters count: " +
-            grid$.reduce$[Int, Int](for (w <- input.split(" ")) yield () => w.length, _.sum, null)
+            ignite.reduce$[Int, Int](for (w <- input.split(" ")) yield () => w.length, _.sum, null)
         )
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/BasicExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/BasicExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/BasicExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..f2ce6fe
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/BasicExamplesMultiNodeSelfTest.java
@@ -0,0 +1,28 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * Closure examples multi-node self test.
+ */
+public class BasicExamplesMultiNodeSelfTest extends BasicExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        startRemoteNodes();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/BasicExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/BasicExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/BasicExamplesSelfTest.java
new file mode 100644
index 0000000..e95b0cc
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/BasicExamplesSelfTest.java
@@ -0,0 +1,82 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.compute.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Closure examples self test.
+ */
+public class BasicExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testBroadcastExample() throws Exception {
+        ComputeBroadcastExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCallableExample() throws Exception {
+        ComputeCallableExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testClosureExample() throws Exception {
+        ComputeClosureExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testExecutorExample() throws Exception {
+        ComputeExecutorServiceExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testReducerExample() throws Exception {
+        ComputeReducerExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testRunnableExample() throws Exception {
+        ComputeRunnableExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testTaskMapExample() throws Exception {
+        ComputeTaskMapExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testTaskSplitExample() throws Exception {
+        ComputeTaskSplitExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/CacheExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/CacheExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/CacheExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..27bac02
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/CacheExamplesMultiNodeSelfTest.java
@@ -0,0 +1,48 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * Cache examples multi-node self test.
+ */
+public class CacheExamplesMultiNodeSelfTest extends CacheExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override protected String defaultConfig() {
+        return "examples/config/example-cache.xml";
+    }
+
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        startRemoteNodes();
+    }
+
+    /** {@inheritDoc} */
+    @Override protected long getTestTimeout() {
+        return 10 * 60 * 1000;
+    }
+
+    /** {@inheritDoc} */
+    @Override public void testCacheStoreExample() throws Exception {
+        // No-op.
+    }
+
+    /** {@inheritDoc} */
+    @Override public void testCacheStoreLoaderExample() throws Exception {
+        // No-op.
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/CacheExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/CacheExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/CacheExamplesSelfTest.java
new file mode 100644
index 0000000..f541390
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/CacheExamplesSelfTest.java
@@ -0,0 +1,155 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.datagrid.*;
+import org.apache.ignite.examples.datagrid.datastructures.*;
+import org.apache.ignite.examples.datagrid.starschema.*;
+import org.apache.ignite.examples.datagrid.store.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Cache examples self test.
+ */
+public class CacheExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheAffinityExample() throws Exception {
+        CacheAffinityExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheAtomicLongExample() throws Exception {
+        CacheAtomicLongExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheAtomicReferenceExample() throws Exception {
+        CacheAtomicReferenceExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheAtomicSequenceExample() throws Exception {
+        CacheAtomicSequenceExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheAtomicStampedExample() throws Exception {
+        CacheAtomicStampedExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheCountDownLatchExample() throws Exception {
+        CacheCountDownLatchExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheQueueExample() throws Exception {
+        CacheQueueExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheSetExample() throws Exception {
+        CacheSetExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheStoreExample() throws Exception {
+        CacheStoreExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheQueryExample() throws Exception {
+        CacheQueryExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheApiExample() throws Exception {
+        CacheApiExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheTransactionExample() throws Exception {
+        CacheTransactionExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheDataLoaderExample() throws Exception {
+        CacheDataLoaderExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testPopularNumbersRealTimeExample() throws Exception {
+        CachePopularNumbersExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheStoreLoaderExample() throws Exception {
+        CacheStoreLoadDataExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCachePutGetExample() throws Exception {
+        CachePutGetExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testSnowflakeSchemaExample() throws Exception {
+        CacheStarSchemaExample.main(EMPTY_ARGS);
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testCacheContinuousQueryExample() throws Exception {
+        CacheContinuousQueryExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/CacheStoreLoadDataExampleMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/CacheStoreLoadDataExampleMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/CacheStoreLoadDataExampleMultiNodeSelfTest.java
new file mode 100644
index 0000000..dc160c9
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/CacheStoreLoadDataExampleMultiNodeSelfTest.java
@@ -0,0 +1,39 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.datagrid.store.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ *
+ */
+public class CacheStoreLoadDataExampleMultiNodeSelfTest extends AbstractExamplesTest {
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        for (int i = 0; i < RMT_NODES_CNT; i++)
+            startGrid("node-" + i, CacheNodeWithStoreStartup.configure());
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridCacheStoreLoaderExample() throws Exception {
+        CacheStoreLoadDataExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/CheckpointExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/CheckpointExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/CheckpointExamplesSelfTest.java
new file mode 100644
index 0000000..54e3c22
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/CheckpointExamplesSelfTest.java
@@ -0,0 +1,45 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.compute.failover.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Checkpoint examples self test.
+ */
+public class CheckpointExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * Starts remote nodes before each test.
+     *
+     * Note: using beforeTestsStarted() to start nodes only once won't work.
+     *
+     * @throws Exception If remote nodes start failed.
+     */
+    @Override protected void beforeTest() throws Exception {
+        for (int i = 0; i < RMT_NODES_CNT; i++)
+            startGrid("node-" + i, ComputeFailoverNodeStartup.configuration());
+    }
+
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridCheckpointExample() throws Exception {
+        ComputeFailoverExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..8b0d305
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesMultiNodeSelfTest.java
@@ -0,0 +1,28 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * Continuation example multi-node self test.
+ */
+public class ContinuationExamplesMultiNodeSelfTest extends ContinuationExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        startRemoteNodes();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesSelfTest.java
new file mode 100644
index 0000000..48ca73e
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/ContinuationExamplesSelfTest.java
@@ -0,0 +1,33 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.compute.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Continuation example self test.
+ */
+public class ContinuationExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridContinuationExample() throws Exception {
+        ComputeFibonacciContinuationExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..59bc10d
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesMultiNodeSelfTest.java
@@ -0,0 +1,28 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * GridContinuousMapperExample multi-node self test.
+ */
+public class ContinuousMapperExamplesMultiNodeSelfTest extends ContinuationExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        startRemoteNodes();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesSelfTest.java
new file mode 100644
index 0000000..cbb79d6
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/ContinuousMapperExamplesSelfTest.java
@@ -0,0 +1,33 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.compute.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * GridContinuousMapperExample self test.
+ */
+public class ContinuousMapperExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridContinuousMapperExample() throws Exception {
+        ComputeContinuousMapperExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..7141d4c
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesMultiNodeSelfTest.java
@@ -0,0 +1,30 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * Deployment examples multi-node self test.
+ */
+public class DeploymentExamplesMultiNodeSelfTest extends DeploymentExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override public void testGridDeploymentExample() throws Exception {
+        startRemoteNodes();
+
+        super.testGridDeploymentExample();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesSelfTest.java
new file mode 100644
index 0000000..8fd4da0
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/DeploymentExamplesSelfTest.java
@@ -0,0 +1,33 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.misc.deployment.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Deployment examples self test.
+ */
+public class DeploymentExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridDeploymentExample() throws Exception {
+        DeploymentExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/EventsExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/EventsExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/EventsExamplesMultiNodeSelfTest.java
new file mode 100644
index 0000000..8ce2aad
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/EventsExamplesMultiNodeSelfTest.java
@@ -0,0 +1,28 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+/**
+ * Events examples multi-node self test.
+ */
+public class EventsExamplesMultiNodeSelfTest extends EventsExamplesSelfTest {
+    /** {@inheritDoc} */
+    @Override protected void beforeTest() throws Exception {
+        startRemoteNodes();
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/EventsExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/EventsExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/EventsExamplesSelfTest.java
new file mode 100644
index 0000000..55341ba
--- /dev/null
+++ b/examples/src/test/java/org/apache/ignite/examples/EventsExamplesSelfTest.java
@@ -0,0 +1,33 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.examples;
+
+import org.apache.ignite.examples.events.*;
+import org.apache.ignite.testframework.junits.common.*;
+
+/**
+ * Events examples self test.
+ */
+public class EventsExamplesSelfTest extends AbstractExamplesTest {
+    /**
+     * @throws Exception If failed.
+     */
+    public void testGridEventsExample() throws Exception {
+        EventsExample.main(EMPTY_ARGS);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesMultiNodeSelfTest.java
deleted file mode 100644
index 191018e..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,28 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * Closure examples multi-node self test.
- */
-public class GridBasicExamplesMultiNodeSelfTest extends GridBasicExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        startRemoteNodes();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesSelfTest.java
deleted file mode 100644
index 4e4a3e6..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridBasicExamplesSelfTest.java
+++ /dev/null
@@ -1,82 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.compute.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Closure examples self test.
- */
-public class GridBasicExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridBroadcastExample() throws Exception {
-        ComputeBroadcastExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCallableExample() throws Exception {
-        ComputeCallableExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridClosureExample() throws Exception {
-        ComputeClosureExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridExecutorExample() throws Exception {
-        ComputeExecutorServiceExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridReducerExample() throws Exception {
-        ComputeReducerExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridRunnableExample() throws Exception {
-        ComputeRunnableExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridTaskMapExample() throws Exception {
-        ComputeTaskMapExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridTaskSplitExample() throws Exception {
-        ComputeTaskSplitExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesMultiNodeSelfTest.java
deleted file mode 100644
index 71621e2..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,48 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * Cache examples multi-node self test.
- */
-public class GridCacheExamplesMultiNodeSelfTest extends GridCacheExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override protected String defaultConfig() {
-        return "examples/config/example-cache.xml";
-    }
-
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        startRemoteNodes();
-    }
-
-    /** {@inheritDoc} */
-    @Override protected long getTestTimeout() {
-        return 10 * 60 * 1000;
-    }
-
-    /** {@inheritDoc} */
-    @Override public void testGridCacheStoreExample() throws Exception {
-        // No-op.
-    }
-
-    /** {@inheritDoc} */
-    @Override public void testGridCacheStoreLoaderExample() throws Exception {
-        // No-op.
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesSelfTest.java
deleted file mode 100644
index 129b8a5..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridCacheExamplesSelfTest.java
+++ /dev/null
@@ -1,155 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.datagrid.*;
-import org.apache.ignite.examples.datagrid.datastructures.*;
-import org.apache.ignite.examples.datagrid.starschema.*;
-import org.apache.ignite.examples.datagrid.store.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Cache examples self test.
- */
-public class GridCacheExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheAffinityExample() throws Exception {
-        CacheAffinityExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheAtomicLongExample() throws Exception {
-        CacheAtomicLongExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheAtomicReferenceExample() throws Exception {
-        CacheAtomicReferenceExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheAtomicSequenceExample() throws Exception {
-        CacheAtomicSequenceExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheAtomicStampedExample() throws Exception {
-        CacheAtomicStampedExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheCountDownLatchExample() throws Exception {
-        CacheCountDownLatchExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheQueueExample() throws Exception {
-        CacheQueueExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheSetExample() throws Exception {
-        CacheSetExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheStoreExample() throws Exception {
-        CacheStoreExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheQueryExample() throws Exception {
-        CacheQueryExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheApiExample() throws Exception {
-        CacheApiExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheTransactionExample() throws Exception {
-        CacheTransactionExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheDataLoaderExample() throws Exception {
-        CacheDataLoaderExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridPopularNumbersRealTimeExample() throws Exception {
-        CachePopularNumbersExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheStoreLoaderExample() throws Exception {
-        CacheStoreLoadDataExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCachePutGetExample() throws Exception {
-        CachePutGetExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridSnowflakeSchemaExample() throws Exception {
-        CacheStarSchemaExample.main(EMPTY_ARGS);
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheContinuousQueryExample() throws Exception {
-        CacheContinuousQueryExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridCacheStoreLoadDataExampleMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridCacheStoreLoadDataExampleMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridCacheStoreLoadDataExampleMultiNodeSelfTest.java
deleted file mode 100644
index 5edea86..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridCacheStoreLoadDataExampleMultiNodeSelfTest.java
+++ /dev/null
@@ -1,39 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.datagrid.store.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- *
- */
-public class GridCacheStoreLoadDataExampleMultiNodeSelfTest extends GridAbstractExamplesTest {
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        for (int i = 0; i < RMT_NODES_CNT; i++)
-            startGrid("node-" + i, CacheNodeWithStoreStartup.configure());
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCacheStoreLoaderExample() throws Exception {
-        CacheStoreLoadDataExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridCheckpointExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridCheckpointExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridCheckpointExamplesSelfTest.java
deleted file mode 100644
index 228b30f..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridCheckpointExamplesSelfTest.java
+++ /dev/null
@@ -1,45 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.compute.failover.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Checkpoint examples self test.
- */
-public class GridCheckpointExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * Starts remote nodes before each test.
-     *
-     * Note: using beforeTestsStarted() to start nodes only once won't work.
-     *
-     * @throws Exception If remote nodes start failed.
-     */
-    @Override protected void beforeTest() throws Exception {
-        for (int i = 0; i < RMT_NODES_CNT; i++)
-            startGrid("node-" + i, ComputeFailoverNodeStartup.configuration());
-    }
-
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridCheckpointExample() throws Exception {
-        ComputeFailoverExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesMultiNodeSelfTest.java
deleted file mode 100644
index f97ccac..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,28 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * Continuation example multi-node self test.
- */
-public class GridContinuationExamplesMultiNodeSelfTest extends GridContinuationExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        startRemoteNodes();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesSelfTest.java
deleted file mode 100644
index 165d640..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridContinuationExamplesSelfTest.java
+++ /dev/null
@@ -1,33 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.compute.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Continuation example self test.
- */
-public class GridContinuationExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridContinuationExample() throws Exception {
-        ComputeFibonacciContinuationExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesMultiNodeSelfTest.java
deleted file mode 100644
index 2a549c1..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,28 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * GridContinuousMapperExample multi-node self test.
- */
-public class GridContinuousMapperExamplesMultiNodeSelfTest extends GridContinuationExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        startRemoteNodes();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesSelfTest.java
deleted file mode 100644
index babf8ea..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridContinuousMapperExamplesSelfTest.java
+++ /dev/null
@@ -1,33 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.compute.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * GridContinuousMapperExample self test.
- */
-public class GridContinuousMapperExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridContinuousMapperExample() throws Exception {
-        ComputeContinuousMapperExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesMultiNodeSelfTest.java
deleted file mode 100644
index 265d44d..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,30 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * Deployment examples multi-node self test.
- */
-public class GridDeploymentExamplesMultiNodeSelfTest extends GridDeploymentExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override public void testGridDeploymentExample() throws Exception {
-        startRemoteNodes();
-
-        super.testGridDeploymentExample();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesSelfTest.java
deleted file mode 100644
index cdade73..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridDeploymentExamplesSelfTest.java
+++ /dev/null
@@ -1,33 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.misc.deployment.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Deployment examples self test.
- */
-public class GridDeploymentExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridDeploymentExample() throws Exception {
-        DeploymentExample.main(EMPTY_ARGS);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesMultiNodeSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesMultiNodeSelfTest.java
deleted file mode 100644
index e2cb5f7..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesMultiNodeSelfTest.java
+++ /dev/null
@@ -1,28 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-/**
- * Events examples multi-node self test.
- */
-public class GridEventsExamplesMultiNodeSelfTest extends GridEventsExamplesSelfTest {
-    /** {@inheritDoc} */
-    @Override protected void beforeTest() throws Exception {
-        startRemoteNodes();
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesSelfTest.java
----------------------------------------------------------------------
diff --git a/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesSelfTest.java b/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesSelfTest.java
deleted file mode 100644
index f159f1a..0000000
--- a/examples/src/test/java/org/apache/ignite/examples/GridEventsExamplesSelfTest.java
+++ /dev/null
@@ -1,33 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package org.apache.ignite.examples;
-
-import org.apache.ignite.examples.events.*;
-import org.apache.ignite.testframework.junits.common.*;
-
-/**
- * Events examples self test.
- */
-public class GridEventsExamplesSelfTest extends GridAbstractExamplesTest {
-    /**
-     * @throws Exception If failed.
-     */
-    public void testGridEventsExample() throws Exception {
-        EventsExample.main(EMPTY_ARGS);
-    }
-}
diff --git a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
index 0605a8c..f239547 100644
--- a/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
+++ b/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCachePopularNumbersExample.scala
@@ -36,7 +36,7 @@ import scala.util.Random
  * start node with `examples/config/example-cache.xml` configuration.
  * <p>
  * The counts are kept in cache on all remote nodes. Top `10` counts from each node are then grabbed to produce
  * an overall top `10` list within the grid.
  */
 object ScalarCachePopularNumbersExample extends App {
     /** Cache name. */
@@ -58,7 +58,7 @@ object ScalarCachePopularNumbersExample extends App {
         println()
         println(">>> Cache popular numbers example started.")
 
-        val prj = grid$.cluster().forCache(CACHE_NAME)
+        val prj = ignite.cluster().forCache(CACHE_NAME)
 
         if (prj.nodes().isEmpty)
             println("Grid does not have cache configured: " + CACHE_NAME);
@@ -75,7 +75,7 @@ object ScalarCachePopularNumbersExample extends App {
                 query(POPULAR_NUMBERS_CNT)
 
                 // Clean up caches on all nodes after run.
-                grid$.cluster().forCache(CACHE_NAME).bcastRun(() => grid$.cache(CACHE_NAME).clearAll(), null)
+                ignite.cluster().forCache(CACHE_NAME).bcastRun(() => ignite.cache(CACHE_NAME).clearAll(), null)
             }
             finally {
                 popularNumbersQryTimer.cancel()

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/scala/org/apache/ignite/scalar/examples/ScalarCacheQueryExample.scala
----------------------------------------------------------------------
@@ -36,7 +36,7 @@ import scala.util.Random
  * <p>
  * The counts are kept in cache on all remote nodes. Top `10` counts from each node are then grabbed to produce
- * an overall top `10` list within the grid.
+ * an overall top `10` list within the ignite.
  */
 object ScalarCachePopularNumbersExample extends App {